/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2006, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.ws.jaxws.jbws2419;

import static javax.xml.ws.soap.SOAPBinding.SOAP12HTTP_BINDING;

import java.io.IOException;

import javax.activation.DataHandler;
import javax.annotation.Resource;
import javax.jws.HandlerChain;
import javax.jws.WebService;
import javax.xml.bind.annotation.XmlMimeType;
import javax.xml.soap.SOAPEnvelope;
import javax.xml.soap.SOAPException;
import javax.xml.soap.SOAPMessage;
import javax.xml.ws.BindingType;
import javax.xml.ws.WebServiceContext;
import javax.xml.ws.WebServiceException;
import javax.xml.ws.handler.soap.SOAPMessageContext;
import javax.xml.ws.soap.MTOM;

import org.jboss.logging.Logger;

@WebService(name="SOAP12Endpoint", targetNamespace="http://org.jboss.ws/jaxws/jbws2419", 
      endpointInterface = "org.jboss.test.ws.jaxws.jbws2419.SOAP12Endpoint")
@BindingType(SOAP12HTTP_BINDING)
@MTOM
@HandlerChain(file = "jaxws-server-handlers2.xml")
public class SOAP12EndpointBean implements SOAP12Endpoint
{
   private static Logger log = Logger.getLogger(SOAP12EndpointBean.class);

   @Resource
   public WebServiceContext context;

   @XmlMimeType("text/plain")
   public DataHandler namespace(@XmlMimeType("text/plain") DataHandler data)
   {
      try
      {
         String name = (String)data.getContent();
         String type = (String)data.getContentType();
         log.info("User " + name + " requested namespace with content type ["+ type +"]");

         SOAPMessageContext msgContext = (SOAPMessageContext)context.getMessageContext();
         SOAPMessage soapMessage = msgContext.getMessage();
         SOAPEnvelope soapEnvelope = (SOAPEnvelope)soapMessage.getSOAPPart().getEnvelope();
         String nsURI = soapEnvelope.getNamespaceURI();

         log.info(nsURI);

         return new DataHandler(nsURI, "text/plain");
      }
      catch (IOException e)
      {
         throw new WebServiceException(e);
      }
      catch (SOAPException ex)
      {
         throw new WebServiceException(ex);
      }
   }
}
